See here: https://github.com/akhilsadam/perceptual-jp-colormaps/blob/master/src/README.md

Tests : [![Python package](https://github.com/akhilsadam/perceptual-jp-colormaps/actions/workflows/python-package.yml/badge.svg)](https://github.com/akhilsadam/perceptual-jp-colormaps/actions/workflows/python-package.yml)
